XML Form

# Loading/Saving a Dynamic Form using XML

This is a very simple example of using XML for load and submit of data with an Ext dynamic form.

Click "Load" to load the dummy XML data from the server using an XmlReader.

After loading the form, you will be able to hit submit. The submit action will make a post to the server, and the dummy XML file on the server with test server-side validation failure messages will be sent back. Those messages will be applied to the appropriate fields in the form.

Note: The built-in JSON support does not require any special readers for mapping. However, If you don't like the Form's built-in JSON format, you could also use a JsonReader for reading data into a form.

The js is not minified so it is readable. See xml-form.js.